module Pod
  class Command
    # This is an example of a cocoapods plugin adding a top-level subcommand
    # to the 'pod' command.
    #
    # You can also create subcommands of existing or new commands. Say you
    # wanted to add a subcommand to `list` to show newly deprecated pods,
    # (e.g. `pod list deprecated`), there are a few things that would need
    # to change.
    #
    # - move this file to `lib/pod/command/list/deprecated.rb` and update
    #   the class to exist in the the Pod::Command::List namespace
    # - change this class to extend from `List` instead of `Command`. This
    #   tells the plugin system that it is a subcommand of `list`.
    # - edit `lib/cocoapods_plugins.rb` to require this file
    #
    # @todo Create a PR to add your plugin to CocoaPods/cocoapods.org
    #       in the `plugins.json` file, once your plugin is released.
    #
    class Fmwk < Command
      class Build < Fmwk
        self.summary = 'Build framework!'

        self.description = <<-DESC
          Build framework...!
        DESC

        def self.options
          [
            ['--workspace', '构建 workspace，若不指定，默认为构建 project'],
            # ['--allow-warnings', 'Lint validates even if warnings are present'],
            # ['--subspec=NAME', 'Lint validates only the given subspec'],
            # ['--no-subspecs', 'Lint skips validation of subspecs'],
            # ['--no-clean', 'Lint leaves the build directory intact for inspection'],
            # ['--fail-fast', 'Lint stops on the first failing platform or subspec'],
            # ['--use-libraries', 'Lint uses static libraries to install the spec'],
            # ['--sources=https://github.com/artsy/Specs,master', 'The sources from which to pull dependent pods ' \
            #   '(defaults to https://github.com/CocoaPods/Specs.git). ' \
            #   'Multiple sources must be comma-delimited.'],
            # ['--private', 'Lint skips checks that apply only to public specs'],
            # ['--swift-version=VERSION', 'The SWIFT_VERSION that should be used to lint the spec. ' \
            #   'This takes precedence over a .swift-version file.'],
            # ['--skip-import-validation', 'Lint skips validating that the pod can be imported'],
            # ['--skip-tests', 'Lint skips building and running tests during validation'],
          ].concat(super)
        end

        def initialize(argv)
          @workspace           = argv.flag?('workspace')
          # @allow_warnings  = argv.flag?('allow-warnings')
          # @clean           = argv.flag?('clean', true)
          # @fail_fast       = argv.flag?('fail-fast', false)
          # @subspecs        = argv.flag?('subspecs', true)
          # @only_subspec    = argv.option('subspec')
          # @use_frameworks  = !argv.flag?('use-libraries')
          # @source_urls     = argv.option('sources', 'https://github.com/CocoaPods/Specs.git').split(',')
          # @private         = argv.flag?('private', false)
          # @swift_version   = argv.option('swift-version', nil)
          # @skip_import_validation = argv.flag?('skip-import-validation', false)
          # @skip_tests = argv.flag?('skip-tests', false)
          @framework_names = argv.arguments!
          super
        end

        def validate!
          super
        end

        def run
          framework_names.each do |podspec|
            `rm -rf #{build_path}` unless !Dir.exist?(build_path)

            puts "打真机包..."
            puts

            output = xcodebuild(podspec)
            puts output
            puts 

            puts "打模拟器包..."
            puts
            output = xcodebuild(podspec, :iphonesimulator)
            puts output
            puts
            puts "生成合成包..."
            puts
            `lipo #{derived_data_path}/#{podspec}/Build/Products/Release-iphoneos/#{podspec}.framework/#{podspec} #{derived_data_path}/#{podspec}/Build/Products/Release-iphonesimulator/#{podspec}.framework/#{podspec} -create -output #{build_path}/#{podspec}`
            `cp -r #{derived_data_path}/#{podspec}/Build/Products/Release-iphoneos/#{podspec}.framework #{build_path}/`
            `cp -f #{build_path}/#{podspec} #{build_path}/#{podspec}.framework/`
            `rm #{build_path}/#{podspec}`
            puts "成功输出 framework 于 #{build_path}/#{podspec}.framework/"
            puts
          end
        end

        private

        #----------------------------------------#

        # !@group Private helpers

        # @return [Pathname] The path of the podspec found in the current
        #         working directory.
        #
        # @raise  If no podspec is found.
        # @raise  If multiple podspecs are found.
        #
        def framework_names
          if !@framework_names.empty?
            Array(@framework_names)
          else
            raise Informative, 'Please type in a framework name!'
          end
        end

        def derived_data_path
          path = Dir.home + '/Documents/Temp/DerivedData'
          `mkdir -p #{path}` unless Dir.exist?(path)
          path
        end

        def build_path
          path = Dir.pwd + '/build'
          `mkdir -p #{path}` unless Dir.exist?(path)
          path
        end

        def xcodebuild(target, type = :iphoneos, clean = true)
          if clean
            command = %W(clean build)
          else
            command = []
          end

          if @workspace
            command += %W(-workspace #{target}.xcworkspace)
          else
            command += %W(-project #{target}.xcodeproj)
          end
          command += %W(-scheme #{target} -configuration Release -derivedDataPath #{derived_data_path}/#{target})
          case type
          when :iphoneos then command += %W(-sdk iphoneos)
          when :iphonesimulator then command += %W(-sdk iphonesimulator)
          end
          # command += %W(| xcpretty)
          output, status = _xcodebuild(command)
          output
        end

        def _xcodebuild(command)
          UI.puts 'xcodebuild ' << command.join(' ') if config.verbose
          # Executable.capture_command('xcodebuild', command, :capture => :merge)
          require 'open3'
          Open3.pipeline('xcodebuild ' << command.join(' '), 'xcpretty')
        end
      end
    end
  end
end
