module Pod
  class Command
    # This is an example of a cocoapods plugin adding a top-level subcommand
    # to the 'pod' command.
    #
    # You can also create subcommands of existing or new commands. Say you
    # wanted to add a subcommand to `list` to show newly deprecated pods,
    # (e.g. `pod list deprecated`), there are a few things that would need
    # to change.
    #
    # - move this file to `lib/pod/command/list/deprecated.rb` and update
    #   the class to exist in the the Pod::Command::List namespace
    # - change this class to extend from `List` instead of `Command`. This
    #   tells the plugin system that it is a subcommand of `list`.
    # - edit `lib/cocoapods_plugins.rb` to require this file
    #
    # @todo Create a PR to add your plugin to CocoaPods/cocoapods.org
    #       in the `plugins.json` file, once your plugin is released.
    #
    class Fmwk < Command
      class Create < Fmwk
        self.summary = 'Validates a Pod without simulator'

        self.description = <<-DESC
          Validates the Pod using the files in the working directory without simulator.
        DESC

        def self.options
          [
            # ['--quick', 'Lint skips checks that would require to download and build the spec'],
            # ['--allow-warnings', 'Lint validates even if warnings are present'],
            # ['--subspec=NAME', 'Lint validates only the given subspec'],
            # ['--no-subspecs', 'Lint skips validation of subspecs'],
            # ['--no-clean', 'Lint leaves the build directory intact for inspection'],
            # ['--fail-fast', 'Lint stops on the first failing platform or subspec'],
            # ['--use-libraries', 'Lint uses static libraries to install the spec'],
            # ['--sources=https://github.com/artsy/Specs,master', 'The sources from which to pull dependent pods ' \
            #   '(defaults to https://github.com/CocoaPods/Specs.git). ' \
            #   'Multiple sources must be comma-delimited.'],
            # ['--private', 'Lint skips checks that apply only to public specs'],
            # ['--swift-version=VERSION', 'The SWIFT_VERSION that should be used to lint the spec. ' \
            #   'This takes precedence over a .swift-version file.'],
            # ['--skip-import-validation', 'Lint skips validating that the pod can be imported'],
            # ['--skip-tests', 'Lint skips building and running tests during validation'],
          ].concat(super)
        end

        def initialize(argv)
          # @quick           = argv.flag?('quick')
          # @allow_warnings  = argv.flag?('allow-warnings')
          # @clean           = argv.flag?('clean', true)
          # @fail_fast       = argv.flag?('fail-fast', false)
          # @subspecs        = argv.flag?('subspecs', true)
          # @only_subspec    = argv.option('subspec')
          # @use_frameworks  = !argv.flag?('use-libraries')
          # @source_urls     = argv.option('sources', 'https://github.com/CocoaPods/Specs.git').split(',')
          # @private         = argv.flag?('private', false)
          # @swift_version   = argv.option('swift-version', nil)
          # @skip_import_validation = argv.flag?('skip-import-validation', false)
          # @skip_tests = argv.flag?('skip-tests', false)
          @framework_names = argv.arguments!
          super
        end

        def validate!
          super
        end

        def run
          UI.puts
          framework_names.each do |podspec|
            puts "开始创建 framework 工程 #{podspec}"
            puts "创建目录..."
            `mkdir -p \`pwd\`/#{podspec}/#{podspec}`
            puts "下载模板..."
            `curl http://gitlab.douyuios.com/huangluyang/my-shells/raw/master/framework_template.podspec -o #{podspec}/#{podspec}.podspec`
            `curl http://gitlab.douyuios.com/huangluyang/my-shells/raw/master/LICENSE_template -o #{podspec}/#{podspec}/LICENSE`
            puts "填充模板..."
            `sed -i '' "s/<#lib name#>/#{podspec}/g" #{podspec}/#{podspec}.podspec`
            puts "创建 framework 工程 #{podspec} 成功！"
            puts ""
          end
        end

        private

        #----------------------------------------#

        # !@group Private helpers

        # @return [Pathname] The path of the podspec found in the current
        #         working directory.
        #
        # @raise  If no podspec is found.
        # @raise  If multiple podspecs are found.
        #
        def framework_names
          if !@framework_names.empty?
            Array(@framework_names)
          else
            raise Informative, 'Please type in a framework name!'
          end
        end
      end
    end
  end
end
